@@ -12,7 +12,6 @@ import sys
 import types
 
 import pytest
-from pkg_resources import parse_version
 
 from .django_compat import is_django_unittest  # noqa
 from .fixtures import django_assert_num_queries  # noqa
@@ -53,7 +52,8 @@ INVALID_TEMPLATE_VARS_ENV = "FAIL_INVALID_TEMPLATE_VARS"
 PY2 = sys.version_info[0] == 2
 
 # pytest 4.2 handles unittest setup/teardown itself via wrapping fixtures.
-_handle_unittest_methods = parse_version(pytest.__version__) < parse_version("4.2")
+_pytest_version_info = tuple(int(x) for x in pytest.__version__.split(".", 2)[:2])
+_handle_unittest_methods = _pytest_version_info < (4, 2)
 
 _report_header = []
 
@@ -63,7 +63,7 @@ _report_header = []
 
 def pytest_addoption(parser):
     group = parser.getgroup("django")
-    group._addoption(
+    group.addoption(
         "--reuse-db",
         action="store_true",
         dest="reuse_db",
@@ -71,7 +71,7 @@ def pytest_addoption(parser):
         help="Re-use the testing database if it already exists, "
         "and do not remove it when the test finishes.",
     )
-    group._addoption(
+    group.addoption(
         "--create-db",
         action="store_true",
         dest="create_db",
@@ -79,7 +79,7 @@ def pytest_addoption(parser):
         help="Re-create the database, even if it exists. This "
         "option can be used to override --reuse-db.",
     )
-    group._addoption(
+    group.addoption(
         "--ds",
         action="store",
         type=str,
@@ -87,7 +87,7 @@ def pytest_addoption(parser):
         default=None,
         help="Set DJANGO_SETTINGS_MODULE.",
     )
-    group._addoption(
+    group.addoption(
         "--dc",
         action="store",
         type=str,
@@ -95,7 +95,7 @@ def pytest_addoption(parser):
         default=None,
         help="Set DJANGO_CONFIGURATION.",
     )
-    group._addoption(
+    group.addoption(
         "--nomigrations",
         "--no-migrations",
         action="store_true",
@@ -103,7 +103,7 @@ def pytest_addoption(parser):
         default=False,
         help="Disable Django migrations on test setup",
     )
-    group._addoption(
+    group.addoption(
         "--migrations",
         action="store_false",
         dest="nomigrations",
@@ -113,7 +113,7 @@ def pytest_addoption(parser):
     parser.addini(
         CONFIGURATION_ENV, "django-configurations class to use by pytest-django."
     )
-    group._addoption(
+    group.addoption(
         "--liveserver",
         default=None,
         help="Address and port for the live_server fixture.",
@@ -128,7 +128,7 @@ def pytest_addoption(parser):
         type="bool",
         default=True,
     )
-    group._addoption(
+    group.addoption(
         "--fail-on-template-vars",
         action="store_true",
         dest="itv",
@@ -415,8 +415,22 @@ def pytest_runtest_setup(item):
             _disable_class_methods(item.cls)
 
 
+@pytest.hookimpl(tryfirst=True)
 def pytest_collection_modifyitems(items):
+    # If Django is not configured we don't need to bother
+    if not django_settings_is_configured():
+        return
+
+    from django.test import TestCase, TransactionTestCase
+
     def get_order_number(test):
+        if hasattr(test, "cls") and test.cls:
+            # Beware, TestCase is a subclass of TransactionTestCase
+            if issubclass(test.cls, TestCase):
+                return 0
+            if issubclass(test.cls, TransactionTestCase):
+                return 1
+
         marker_db = test.get_closest_marker('django_db')
         if marker_db:
             transaction = validate_django_db(marker_db)[0]
@@ -506,20 +520,16 @@ def _django_setup_unittest(request, django_db_blocker):
         yield
         return
 
-    from _pytest.unittest import TestCaseFunction
+    # Fix/patch pytest.
+    # Before pytest 5.4: https://github.com/pytest-dev/pytest/issues/5991
+    # After pytest 5.4: https://github.com/pytest-dev/pytest-django/issues/824
+    from _pytest.monkeypatch import MonkeyPatch
 
-    if "debug" in TestCaseFunction.runtest.__code__.co_names:
-        # Fix pytest (https://github.com/pytest-dev/pytest/issues/5991), only
-        # if "self._testcase.debug()" is being used (forward compatible).
-        from _pytest.monkeypatch import MonkeyPatch
+    def non_debugging_runtest(self):
+        self._testcase(result=self)
 
-        def non_debugging_runtest(self):
-            self._testcase(result=self)
-
-        mp_debug = MonkeyPatch()
-        mp_debug.setattr("_pytest.unittest.TestCaseFunction.runtest", non_debugging_runtest)
-    else:
-        mp_debug = None
+    mp_debug = MonkeyPatch()
+    mp_debug.setattr("_pytest.unittest.TestCaseFunction.runtest", non_debugging_runtest)
 
     request.getfixturevalue("django_db_setup")
 
